@@ -261,7 +261,7 @@ Usage::
     search_transit_gateway_multicast_groups_paginator: SearchTransitGatewayMulticastGroupsPaginator = client.get_paginator("search_transit_gateway_multicast_groups")
     ```
 """
-from mypy_boto3_ec2.client import EC2Client as Client, EC2Client
+from mypy_boto3_ec2.client import EC2Client
 from mypy_boto3_ec2.paginator import (
     DescribeByoipCidrsPaginator,
     DescribeCapacityReservationsPaginator,
@@ -286,20 +286,20 @@ from mypy_boto3_ec2.paginator import (
     DescribeImportImageTasksPaginator,
     DescribeImportSnapshotTasksPaginator,
     DescribeInstanceCreditSpecificationsPaginator,
+    DescribeInstancesPaginator,
     DescribeInstanceStatusPaginator,
     DescribeInstanceTypeOfferingsPaginator,
     DescribeInstanceTypesPaginator,
-    DescribeInstancesPaginator,
     DescribeInternetGatewaysPaginator,
     DescribeIpv6PoolsPaginator,
-    DescribeLaunchTemplateVersionsPaginator,
     DescribeLaunchTemplatesPaginator,
+    DescribeLaunchTemplateVersionsPaginator,
+    DescribeLocalGatewayRouteTablesPaginator,
     DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsPaginator,
     DescribeLocalGatewayRouteTableVpcAssociationsPaginator,
-    DescribeLocalGatewayRouteTablesPaginator,
+    DescribeLocalGatewaysPaginator,
     DescribeLocalGatewayVirtualInterfaceGroupsPaginator,
     DescribeLocalGatewayVirtualInterfacesPaginator,
-    DescribeLocalGatewaysPaginator,
     DescribeMovingAddressesPaginator,
     DescribeNatGatewaysPaginator,
     DescribeNetworkAclsPaginator,
@@ -329,11 +329,11 @@ from mypy_boto3_ec2.paginator import (
     DescribeTransitGatewayMulticastDomainsPaginator,
     DescribeTransitGatewayPeeringAttachmentsPaginator,
     DescribeTransitGatewayRouteTablesPaginator,
-    DescribeTransitGatewayVpcAttachmentsPaginator,
     DescribeTransitGatewaysPaginator,
-    DescribeVolumeStatusPaginator,
+    DescribeTransitGatewayVpcAttachmentsPaginator,
     DescribeVolumesModificationsPaginator,
     DescribeVolumesPaginator,
+    DescribeVolumeStatusPaginator,
     DescribeVpcClassicLinkDnsSupportPaginator,
     DescribeVpcEndpointConnectionNotificationsPaginator,
     DescribeVpcEndpointConnectionsPaginator,
@@ -351,10 +351,7 @@ from mypy_boto3_ec2.paginator import (
     SearchLocalGatewayRoutesPaginator,
     SearchTransitGatewayMulticastGroupsPaginator,
 )
-from mypy_boto3_ec2.service_resource import (
-    EC2ServiceResource as ServiceResource,
-    EC2ServiceResource,
-)
+from mypy_boto3_ec2.service_resource import EC2ServiceResource
 from mypy_boto3_ec2.waiter import (
     BundleTaskCompleteWaiter,
     ConversionTaskCancelledWaiter,
@@ -390,6 +387,11 @@ from mypy_boto3_ec2.waiter import (
     VpnConnectionDeletedWaiter,
 )
 
+Client = EC2Client
+
+
+ServiceResource = EC2ServiceResource
+
 
 __all__ = (
     "BundleTaskCompleteWaiter",
